package kernel;

import kernel.service.ServiceManager;
import kernel.binstore.BinStore;
import kernel.gps.INS;
import kernel.fs.FS;
import kernel.gps.GPS;
import kernel.log.Log;
import kernel.turtle.Turtle;
import haxe.MainLoop;
import kernel.net.Routing;
import cc.OS;
import lib.Debug;
import kernel.ui.WindowManager;
import kernel.peripherals.Peripherals.Peripheral;
import kernel.net.Net;
import kernel.DCEHack; // Important for DCE hack

class Init {
	@:allow(kernel.KernelEvents)
	private static var mainEvent:MainEvent;

	public static function initKernel() {
		// Init singeltons here because haxe is confused about the order to create them.
		Log.init();
		KernelEvents.init();

		WindowManager.init();
		MainTerm.instance = new MainTerm();

		Routing.init();
		Net.init();

		GPS.init();

		// Register default terminate handler
		KernelEvents.onTerminate.handle(_ -> {
			KernelEvents.shutdown();
		});

		Debug.printBuildInfo();

		if (!FS.exists("/var/ns")) {
			FS.makeDir("/var/ns");
		}

		Init.mainEvent = MainLoop.add(() -> {
			KernelEvents.startEventLoop();
		});

		ServiceManager.init();
	}
}
